@@ -6,8 +6,10 @@ import funcnodes as fn
 from exposedfunctionality.function_parser.types import add_type
 from . import plots, layout, figure, express
 import os
+import json
 
 import funcnodes_pandas  # noqa: F401
+import funcnodes_numpy  # noqa: F401
 
 add_type(
     go.Figure,
@@ -36,7 +38,8 @@ def figureencoder(figure: go.Figure, preview: bool = False) -> Tuple[Any, bool]:
         return fn.Encdata(
             data=figure.to_plotly_json(),
             handeled=True,
-            done=True,
+            done=False,
+            continue_preview=False,
         )
     return fn.Encdata(
         data=figure,
@@ -47,6 +50,27 @@ def figureencoder(figure: go.Figure, preview: bool = False) -> Tuple[Any, bool]:
 fn.JSONEncoder.add_encoder(figureencoder)
 
 
+def figure_byte_encoder(figure: go.Figure, preview) -> fn.BytesEncdata:
+    if isinstance(figure, go.Figure):
+        return fn.BytesEncdata(
+            data=json.dumps(
+                fn.JSONEncoder.apply_custom_encoding(figure, preview=preview)
+            ).encode("utf-8"),
+            handeled=True,
+            mime="application/json",
+        )
+    return fn.BytesEncdata(
+        data=figure,
+        handeled=False,
+    )
+
+
+fn.ByteEncoder.add_encoder(
+    figure_byte_encoder,
+    enc_cls=[go.Figure],
+)
+
+
 NODE_SHELF = fn.Shelf(
     nodes=[],
     name="Plotly",
@@ -65,4 +89,4 @@ REACT_PLUGIN = {
 }
 
 
-__version__ = "0.2.6"
+__version__ = "0.3.1"
